<?php
/**
 * NaturalAtlas.php
 *
 * @package Embera
 * @author Michael Pratt <yo@michael-pratt.com>
 * @link   http://www.michael-pratt.com/
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Embera\Provider;

use Embera\Url;

/**
 * NaturalAtlas Provider
 * Explore the outdoors on Natural Atlas – campgrounds, trails, waterfalls, hot springs, and mor...
 *
 * @link https://naturalatlas.com
 *
 */
class NaturalAtlas extends ProviderAdapter implements ProviderInterface
{
    /** inline {@inheritdoc} */
    protected $endpoint = 'https://naturalatlas.com/oembed.json';

    /** inline {@inheritdoc} */
    protected static $hosts = [
        'naturalatlas.com'
    ];

    /** inline {@inheritdoc} */
    protected $httpsSupport = true;

    /** inline {@inheritdoc} */
    protected $responsiveSupport = false;

    /** inline {@inheritdoc} */
    public function validateUrl(Url $url)
    {
        return (bool) (preg_match('~naturalatlas\.com/(.+)[0-9]+$~i', (string) $url));
    }

    /** inline {@inheritdoc} */
    public function normalizeUrl(Url $url)
    {
        $url->convertToHttps();
        $url->removeQueryString();
        $url->removeLastSlash();

        return $url;
    }

}
